# foundation-design-system
Envato foundation design system

### Guide for writing tokens

```yml
---
  # global is required and category needs to be defined at the top of each file
  global:
    category: "app"
  # use `imports` to import other files
  imports:
    [
      "./colors.yml",
      "./fonts.yml"
    ]
  # props is required to write `key` and `value` pair
  props:
    header:
      value: "'Arial Black', 'Arial Bold', Gadget, sans-serif"
      # type is not used in the generated result but is required by the plugin
      # it can be help to make the code more readable
      type: "font"
```

| Name | Description | Required |
| --- | --- | --- |
| global | meta information can be put here, will have other sub attribute | True |
| category | category attribute, can be `color`, `font` or whatever, required but not used in the output | True |
| imports | import other files | False |
| props | define your key value pair | True |
| type | type of the attribute, not used in the output but required | True |

### Usage

```sh
$ npm install @envato-foundation/foundation-design-system --save
```

#### Webpack and scss-loader example

Config loaders in `webpack.config.js`

```js
module: {
  loaders: [
    {
      test: /\.scss$/,
      loader: ExtractTextPlugin.extract('style-loader', 'css-loader', 'sass-loader')
    }
  ]
},
plugins: [
  new ExtractTextPlugin('[name].css')
],
resolve: {
  extensions: ['', '.js', '.scss'],
  root: [path.join(__dirname, './node_modules')]
}
```

And then in your code

```js
require('@envato-foundation/foundation-design-system/dist/colors.scss')
```

For a complete example please check the `example` directory.

### Setup

```sh
$ npm install
```

### Development

```sh
$ gulp watch
```

To build

```sh
$ gulp
```

### Deploy style guide sites

```sh
# npm run deploy
```

### License
MIT
